@@ -1,7 +1,7 @@
 __author__ = 'Altertech, https://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2020 Altertech'
 __license__ = 'MIT'
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 
 # TODO: 2fa
 
@@ -404,7 +404,7 @@ def is_confirmed_session():
     return session.get(f'{_d.x_prefix}user_confirmed_session', False)
 
 
-def clear_confirmed_session():
+def stop_confirmed_session():
     """
     Clear confirmed session
 
